@@ -122,10 +122,6 @@ class fpga_compiler:
             end = data[1][row][col][1] + 1
             finished = False
             for r in data[2][start:end]:
-                if r[3] == (0,0,0) and n <= len(outputs):
-                    r[3] = (1, neuronIdx)
-                    finished = True
-                    break
                 for i in range(len(r)):
                     if r[i] == (0, 0, 0) and n <= len(outputs):
                         r[i] = (1, neuronIdx)
